==> cmp-support-ejb-3.0-b39-sources.jar: com/sun/jdo/spi/persistence/support/ejb/ejbqlc/EJBQLTokenTypes.java <==
// $ANTLR 2.7.6 (2005-12-22): "EJBQL.g" -> "EJBQLParser.java"$

    package com.sun.jdo.spi.persistence.support.ejb.ejbqlc;

    import antlr.MismatchedTokenException;
    import antlr.MismatchedCharException;
    import antlr.NoViableAltException;
    import antlr.NoViableAltForCharException;
    import antlr.TokenStreamRecognitionException;
    
    import java.util.ResourceBundle;
    import com.sun.jdo.spi.persistence.utility.I18NHelper;

public interface EJBQLTokenTypes {
	int EOF = 1;
	int NULL_TREE_LOOKAHEAD = 3;
	int SELECT = 4;
	int FROM = 5;
	int WHERE = 6;
	int DISTINCT = 7;
	int OBJECT = 8;
	int NULL = 9;
	int TRUE = 10;
	int FALSE = 11;
	int NOT = 12;
	int AND = 13;
	int OR = 14;
	int BETWEEN = 15;
	int LIKE = 16;
	int IN = 17;
	int AS = 18;
	int UNKNOWN = 19;
	int EMPTY = 20;
	int MEMBER = 21;
	int OF = 22;
	int IS = 23;
	int ESCAPE = 24;
	int CONCAT = 25;
	int SUBSTRING = 26;
	int LOCATE = 27;
	int LENGTH = 28;
	int ABS = 29;
	int SQRT = 30;
	int MOD = 31;
	int AVG = 32;
	int MAX = 33;
	int MIN = 34;
	int SUM = 35;
	int COUNT = 36;
	int ORDER = 37;
	int BY = 38;
	int ASC = 39;
	int DESC = 40;
	int EQUAL = 41;
	int NOT_EQUAL = 42;
	int GE = 43;
	int GT = 44;
	int LE = 45;
	int LT = 46;
	int PLUS = 47;
	int MINUS = 48;
	int STAR = 49;
	int DIV = 50;
	int STRING_LITERAL = 51;
	int INT_LITERAL = 52;
	int LONG_LITERAL = 53;
	int FLOAT_LITERAL = 54;
	int DOUBLE_LITERAL = 55;
	int IDENT = 56;
	int DOT = 57;
	int INPUT_PARAMETER = 58;
	int LPAREN = 59;
	int RPAREN = 60;
	int COMMA = 61;
	int WS = 62;
	int HEX_DIGIT = 63;
	int EXPONENT = 64;
	int FLOAT_SUFFIX = 65;
	int UNICODE_DIGIT = 66;
	int UNICODE_STR = 67;
	int NEWLINE = 68;
	int ESC = 69;
	int FLOATINGPOINT_SUFFIX = 70;
	int UNICODE_ESCAPE = 71;
	int QUERY = 72;
	int RANGE = 73;
	int CMP_FIELD_ACCESS = 74;
	int SINGLE_CMR_FIELD_ACCESS = 75;
	int COLLECTION_CMR_FIELD_ACCESS = 76;
	int IDENTIFICATION_VAR = 77;
	int IDENTIFICATION_VAR_DECL = 78;
	int ABSTRACT_SCHEMA_NAME = 79;
	int CMP_FIELD = 80;
	int SINGLE_CMR_FIELD = 81;
	int COLLECTION_CMR_FIELD = 82;
	int UNARY_MINUS = 83;
	int UNARY_PLUS = 84;
	int NOT_BETWEEN = 85;
	int NOT_LIKE = 86;
	int NOT_IN = 87;
	int NOT_NULL = 88;
	int NOT_EMPTY = 89;
	int NOT_MEMBER = 90;
}

==> cmp-support-ejb-6.2.0-sources.jar: com/sun/jdo/spi/persistence/support/ejb/ejbqlc/EJBQLTokenTypes.java <==
// $ANTLR 2.7.7 (20060906): "EJBQL.g" -> "EJBQLParser.java"$

    package com.sun.jdo.spi.persistence.support.ejb.ejbqlc;

    import antlr.MismatchedTokenException;
    import antlr.MismatchedCharException;
    import antlr.NoViableAltException;
    import antlr.NoViableAltForCharException;
    import antlr.TokenStreamRecognitionException;
    
    import java.util.ResourceBundle;
    import org.glassfish.persistence.common.I18NHelper;

public interface EJBQLTokenTypes {
	int EOF = 1;
	int NULL_TREE_LOOKAHEAD = 3;
	int SELECT = 4;
	int FROM = 5;
	int WHERE = 6;
	int DISTINCT = 7;
	int OBJECT = 8;
	int NULL = 9;
	int TRUE = 10;
	int FALSE = 11;
	int NOT = 12;
	int AND = 13;
	int OR = 14;
	int BETWEEN = 15;
	int LIKE = 16;
	int IN = 17;
	int AS = 18;
	int UNKNOWN = 19;
	int EMPTY = 20;
	int MEMBER = 21;
	int OF = 22;
	int IS = 23;
	int ESCAPE = 24;
	int CONCAT = 25;
	int SUBSTRING = 26;
	int LOCATE = 27;
	int LENGTH = 28;
	int ABS = 29;
	int SQRT = 30;
	int MOD = 31;
	int AVG = 32;
	int MAX = 33;
	int MIN = 34;
	int SUM = 35;
	int COUNT = 36;
	int ORDER = 37;
	int BY = 38;
	int ASC = 39;
	int DESC = 40;
	int EQUAL = 41;
	int NOT_EQUAL = 42;
	int GE = 43;
	int GT = 44;
	int LE = 45;
	int LT = 46;
	int PLUS = 47;
	int MINUS = 48;
	int STAR = 49;
	int DIV = 50;
	int STRING_LITERAL = 51;
	int INT_LITERAL = 52;
	int LONG_LITERAL = 53;
	int FLOAT_LITERAL = 54;
	int DOUBLE_LITERAL = 55;
	int IDENT = 56;
	int DOT = 57;
	int INPUT_PARAMETER = 58;
	int LPAREN = 59;
	int RPAREN = 60;
	int COMMA = 61;
	int WS = 62;
	int HEX_DIGIT = 63;
	int EXPONENT = 64;
	int FLOAT_SUFFIX = 65;
	int UNICODE_DIGIT = 66;
	int UNICODE_STR = 67;
	int NEWLINE = 68;
	int ESC = 69;
	int FLOATINGPOINT_SUFFIX = 70;
	int UNICODE_ESCAPE = 71;
	int QUERY = 72;
	int RANGE = 73;
	int CMP_FIELD_ACCESS = 74;
	int SINGLE_CMR_FIELD_ACCESS = 75;
	int COLLECTION_CMR_FIELD_ACCESS = 76;
	int IDENTIFICATION_VAR = 77;
	int IDENTIFICATION_VAR_DECL = 78;
	int ABSTRACT_SCHEMA_NAME = 79;
	int CMP_FIELD = 80;
	int SINGLE_CMR_FIELD = 81;
	int COLLECTION_CMR_FIELD = 82;
	int UNARY_MINUS = 83;
	int UNARY_PLUS = 84;
	int NOT_BETWEEN = 85;
	int NOT_LIKE = 86;
	int NOT_IN = 87;
	int NOT_NULL = 88;
	int NOT_EMPTY = 89;
	int NOT_MEMBER = 90;
}
